@@ -84,6 +84,7 @@ tar_map2 <- function(
   columns2 = tidyselect::everything(),
   rep_workers = 1,
   delimiter = "_",
+  unlist = FALSE,
   tidy_eval = targets::tar_option_get("tidy_eval"),
   packages = targets::tar_option_get("packages"),
   library = targets::tar_option_get("library"),
@@ -115,6 +116,7 @@ tar_map2 <- function(
     columns2 = substitute(columns2),
     rep_workers = rep_workers,
     delimiter = delimiter,
+    unlist = unlist,
     tidy_eval = tidy_eval,
     packages = packages,
     library = library,
