@@ -15,6 +15,7 @@ tar_map2_count_raw <- function(
   columns2 = quote(tidyselect::everything()),
   rep_workers = 1,
   delimiter = "_",
+  unlist = FALSE,
   tidy_eval = targets::tar_option_get("tidy_eval"),
   packages = targets::tar_option_get("packages"),
   library = targets::tar_option_get("library"),
@@ -53,6 +54,7 @@ tar_map2_count_raw <- function(
     columns2 = columns2,
     rep_workers = rep_workers,
     delimiter = delimiter,
+    unlist = unlist,
     tidy_eval = tidy_eval,
     packages = packages,
     library = library,
