@@ -415,13 +415,17 @@ tar_quarto_rep_rep <- function(
   default_output_file,
   seeds
 ) {
-  withr::local_options(list(crayon.enabled = NULL))
-  directory <- dirname(default_output_file)
-  fs::dir_create(directory)
-  destination <- basename(execute_params[["output_file"]])
-  destination_file <- file.path(directory, destination)
-  extension <- paste0(".", fs::path_ext(destination_file))
+  temporary_directory <- dirname(default_output_file)
+  destination_directory <- dirname(
+    execute_params[["output_file"]] %|||% default_output_file
+  )
+  fs::dir_create(temporary_directory)
+  fs::dir_create(destination_directory)
+  destination_basename <- basename(execute_params[["output_file"]])
+  destination_file <- file.path(destination_directory, destination_basename)
+  extension <- paste0(".", fs::path_ext(destination_basename))
   temporary_basename <- basename(tempfile(fileext = extension))
+  temporary_file <- file.path(temporary_directory, temporary_basename)
   args$output_file <- temporary_basename
   args$execute_params <- execute_params
   args$execute_params[["output_file"]] <- NULL
@@ -429,7 +433,7 @@ tar_quarto_rep_rep <- function(
   seed <- as.integer(if_any(anyNA(seeds), NA_integer_, seeds[rep]))
   if_any(anyNA(seed), NULL, targets::tar_seed_set(seed = seed))
   result <- do.call(quarto::quarto_render, args)
-  fs::file_move(file.path(directory, temporary_basename), destination_file)
+  fs::file_move(temporary_basename, destination_file)
   sort(as.character(fs::path_rel(unlist(destination_file))))
 }
 
