@@ -1,4 +1,4 @@
-make_psock_cluster <- function(workers) {
+make_psock_cluster <- function(workers, export = TRUE) {
   cluster <- parallel::makePSOCKcluster(workers)
   parallel::clusterCall(
     cl = cluster,
@@ -10,5 +10,13 @@ make_psock_cluster <- function(workers) {
     packages = targets::tar_definition()$command$packages,
     library = targets::tar_definition()$command$library
   )
+  if (export) {
+    envir <- targets::tar_option_get("envir")
+    parallel::clusterExport(
+      cl = cluster,
+      varlist = names(envir),
+      envir = envir
+    )
+  }
   cluster
 }
